@@ -7,8 +7,8 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package Const::Fast;
-BEGIN {
-  $Const::Fast::VERSION = '0.007';
+{
+  $Const::Fast::VERSION = '0.00701';
 }
 
 use 5.008;
@@ -29,7 +29,10 @@ sub _make_readonly {
 		my $needs_cloning = !$dont_clone && &Internals::SvREFCNT($_[0]) > 1;
 		$_[0] = dclone($_[0]) if $needs_cloning;
 		&Internals::SvREADONLY($_[0], 1);
-		if ($reftype eq 'ARRAY') {
+		if ($reftype eq 'SCALAR' || $reftype eq 'REF') {
+			_make_readonly(${ $_[0] }, 1);
+		}
+		elsif ($reftype eq 'ARRAY') {
 			_make_readonly($_) for @{ $_[0] };
 		}
 		elsif ($reftype eq 'HASH') {
@@ -78,7 +81,7 @@ Const::Fast - Facility for creating read-only scalars, arrays, and hashes
 
 =head1 VERSION
 
-version 0.007
+version 0.00701
 
 =head1 SYNOPSIS
 
